pub enum Action {
Continue(PacketContext),
Send(PacketContext, SmallVec<[FaceId; 4]>),
Satisfy(PacketContext),
Drop(DropReason),
Nack(PacketContext, NackReason),
}Expand description
The return value from a pipeline stage.
Ownership-based: Continue returns the context back to the runner.
All other variants consume the context, making it a compiler error to
use the context after it has been handed off.
Variants
Continue(PacketContext)
Pass context to the next stage.
Send(PacketContext, SmallVec<[FaceId; 4]>)
Forward the packet to the given faces and exit the pipeline.
Satisfy(PacketContext)
Satisfy pending PIT entries and exit the pipeline.
Drop(DropReason)
Drop the packet silently.
Nack(PacketContext, NackReason)
Send a Nack back to the incoming face.